function f = fft0n(x, sizeF)
%FFT1N N-dimensional discrete Fourier Transform.
%   FFTN(X) returns the N-dimensional discrete Fourier transform
%   of the N-D array X.  If X is a vector, the output will have
%   the same orientation.
%   FFTN(X,SIZ) pads X so that its size vector is SIZ before
%   performing the transform.  If any element of SIZ is smaller
%   than the corresponding dimension of X, then X will be cropped
%   in that dimension.
%
%   See also FFT, IFFT, FFT2, IFFT2, IFFTN.

%   Steven L. Eddins, January 1996
%   Copyright (c) 1984-97 by The MathWorks, Inc.
%   $Revision: 1.4 $  $Date: 1997/04/08 05:22:22 $

%   Reference: Dudgeon and Mersereau, Multidimensional Digital
%   Signal Processing, Prentice-Hall, 1984.

error(nargchk(1,2,nargin))

% Make sure size vectors have appropriate lengths.
sizeX = size(x);
ndimsIn = length(sizeX);
if (nargin < 2)
  sizeF = sizeX;
  ndimsOut = ndimsIn;
else
  ndimsOut = length(sizeF);
end
if (ndimsOut < ndimsIn)
  % error('SIZ must have at least ndims(X) elements')
elseif (ndimsOut > ndimsIn)
  sizeX = [sizeX ones(1,ndimsOut-ndimsIn)];
end

% Perform the FFT.
f = x;
for p = 1:ndimsOut
  if (p > ndimsIn)
    % Input is impulse in the p-dimension.  FFT won't handle
    % this case directly, but we just need to use REPMAT.
    tmp = ones(1,ndimsOut);
    tmp(p) = sizeF(p);
    f = repmat(f,tmp);
  
  elseif (sizeF(p) ~= sizeX(p))
    % Need to zeropad or crop in this dimension.
    f = fft(f,sizeF(p),p);
  
  else
    % Don't need to zeropad or crop.
    f = fft(f,[],p);
  end

end
