function x = ifftn(f, sizeX)
%IFFTN N-dimensional inverse discrete Fourier transform.
%   IFFTN(F) returns the N-dimensional inverse discrete Fourier
%   transform of the N-D array F.  If F is a vector, the result
%   will have the same orientation.
%   IFFTN(F,SIZ) pads F so that its size vector is SIZ before
%   performing the transform.  If any element of SIZ is smaller
%   than the corresponding dimension of F, then F will be cropped
%   in that dimension.
%
%   See also FFT, IFFT, FFT2, IFFT2, FFTN.

%   Steven L. Eddins, January 1996
%   Copyright (c) 1984-97 by The MathWorks, Inc.
%   $Revision: 1.4 $  $Date: 1997/04/08 05:23:07 $

%   Reference: Dudgeon and Mersereau, Multidimensional Digital
%   Signal Processing, Prentice-Hall, 1984.

error(nargchk(1,2,nargin))

% Make sure size vectors have appropriate lengths.
sizeF = size(f);
ndimsIn = length(sizeF);
if (nargin < 2)
  sizeX = sizeF;
  ndimsOut = ndimsIn;
else
  ndimsOut = length(sizeX);
end
if (ndimsOut < ndimsIn)
  %error('SIZ must have at least ndims(F) elements');
elseif (ndimsOut > ndimsIn)
  sizeF = [sizeF ones(1,ndimsOut-ndimsIn)];
end

% Perform the IFFT.
x = f;
for p = 1:ndimsOut
  if (p > ndimsIn)
    % Input is impulse in the p-dimension.  IFFT won't handle
    % this case directly, but we just need to use REPMAT with the
    % appropriate scale factor.
    tmp = ones(1,ndimsOut);
    tmp(p) = sizeX(p);
    x = repmat(x,tmp) / sizeX(p);
  
  elseif (sizeX(p) ~= sizeF(p))
    % Need to zeropad or crop in this dimension.
    x = ifft(x,sizeX(p),p);
    
  else
    % Don't need to zeropad or crop.
    x = ifft(x,[],p);
    
  end
end

    
